@@ -121,46 +121,48 @@ class NavParser:
 
         talkerID = data[0][1:3]  # $GPGGA -> GP
         sentenceID = data[0][3:]  # $GPGGA -> GGA
+        try:
+            if sentenceID == "GGA":
+                lat_before_conversion = float(data[2])
+                long_before_conversion = float(data[4])
+                lat_dir, long_dir = data[3], data[5]
+                lat, long = NavParser.get_final_lat_long(lat_before_conversion, long_before_conversion,
+                                                         lat_dir, long_dir)
+                if (lat, long) not in self._points:
+                    self._points[lat, long] = NavRowData(lat, long)
+                    self._points[lat, long].set_talkerID(talkerID)
 
-        if sentenceID == "GGA":
-            lat_before_conversion = float(data[2])
-            long_before_conversion = float(data[4])
-            lat_dir, long_dir = data[3], data[5]
-            lat, long = NavParser.get_final_lat_long(lat_before_conversion, long_before_conversion,
-                                                     lat_dir, long_dir)
+                self._points[lat, long].set_satellites_count(int(data[7]))
+
+            elif sentenceID == "RMC":
+                timestamp = datetime.strptime(f"{data[9]} {data[1]}", "%d%m%y %H%M%S.%f")
+                lat_before_conversion = float(data[3])
+                long_before_conversion = float(data[5])
+                speed_kmh = 1.852 * float(data[7])
+                lat_dir, long_dir = data[4], data[6]
+                lat, long = NavParser.get_final_lat_long(lat_before_conversion, long_before_conversion,
+                                                         lat_dir, long_dir)
+                if (lat, long) not in self._points:
+                    self._points[lat, long] = NavRowData(lat, long)
+                    self._points[lat, long].set_talkerID(talkerID)
+
+                self._points[lat, long].set_speed_kmh(speed_kmh)
+                self._points[lat, long].set_timestamp(timestamp)
+                if timestamp > self._points[self.most_recent].get_timestamp():
+                    self.most_recent = (lat, long)
+
+            if lat is None or long is None:
+                return
             if (lat, long) not in self._points:
                 self._points[lat, long] = NavRowData(lat, long)
                 self._points[lat, long].set_talkerID(talkerID)
 
-            self._points[lat, long].set_satellites_count(int(data[7]))
-
-        elif sentenceID == "RMC":
-            timestamp = datetime.strptime(f"{data[9]} {data[1]}", "%d%m%y %H%M%S.%f")
-            lat_before_conversion = float(data[3])
-            long_before_conversion = float(data[5])
-            speed_kmh = 1.852 * float(data[7])
-            lat_dir, long_dir = data[4], data[6]
-            lat, long = NavParser.get_final_lat_long(lat_before_conversion, long_before_conversion,
-                                                     lat_dir, long_dir)
-            if (lat, long) not in self._points:
-                self._points[lat, long] = NavRowData(lat, long)
-                self._points[lat, long].set_talkerID(talkerID)
-
-            self._points[lat, long].set_speed_kmh(speed_kmh)
-            self._points[lat, long].set_timestamp(timestamp)
-            if timestamp > self._points[self.most_recent].get_timestamp():
-                self.most_recent = (lat, long)
-
-        if lat is None or long is None:
-            return
-        if (lat, long) not in self._points:
-            self._points[lat, long] = NavRowData(lat, long)
-            self._points[lat, long].set_talkerID(talkerID)
-
-        if sentenceID == "VTG":
-            self._points[lat, long].set_direction_true(data[1])
-            self._points[lat, long].set_direction_mag(data[3])
-            self._points[lat, long].set_speed_kmh(float(data[7]))
+            if sentenceID == "VTG":
+                self._points[lat, long].set_direction_true(data[1])
+                self._points[lat, long].set_direction_mag(data[3])
+                self._points[lat, long].set_speed_kmh(float(data[7]))
+        except ValueError:
+            pass
 
     def remove_bad_points(self):
         self._points = {k: v for k, v in self._points.items() if v.has_all_data()}
